@@ -527,7 +527,7 @@ get_xattrs (const char            *path,
 	  attr2 = strchr (attr, ':');
 	  if (attr2)
 	    {
-	      attr2++; /* Skip ':' */
+	      attr2 += 2; /* Skip '::' */
 	      unescaped_attribute = hex_unescape_string (attr2, NULL, &free_unescaped_attribute);
 	      if (user)
 		a = g_strconcat ("user.", unescaped_attribute, NULL);
@@ -1500,7 +1500,8 @@ _g_local_file_info_get (const char             *basename,
   if (basename != NULL && basename[0] == '.')
     g_file_info_set_is_hidden (info, TRUE);
 
-  if (basename != NULL && basename[strlen (basename) -1] == '~')
+  if (basename != NULL && basename[strlen (basename) -1] == '~' &&
+      S_ISREG (statbuf.st_mode))
     g_file_info_set_attribute_boolean (info, G_FILE_ATTRIBUTE_STANDARD_IS_BACKUP, TRUE);
 #else
   if (dos_attributes & FILE_ATTRIBUTE_HIDDEN)
@@ -2047,7 +2048,7 @@ set_mtime_atime (char                       *filename,
 
       g_set_error (error, G_IO_ERROR,
 		   g_io_error_from_errno (errsv),
-		   _("Error setting owner: %s"),
+		   _("Error setting modification or access time: %s"),
 		   g_strerror (errsv));
 	  return FALSE;
     }
