@@ -101,10 +101,10 @@ static GResolver *default_resolver;
  * many threads/processes, etc it should allocate for concurrent DNS
  * resolutions.
  *
- * Return value: the #GResolver.
+ * Return value: the default #GResolver.
  *
  * Since: 2.22
- **/
+ */
 GResolver *
 g_resolver_get_default (void)
 {
@@ -353,7 +353,7 @@ g_resolver_free_addresses (GList *addresses)
  * %G_IO_ERROR_CANCELLED.
  *
  * Return value: a hostname (either ASCII-only, or in ASCII-encoded
- * form), or %NULL on error.
+ *     form), or %NULL on error.
  *
  * Since: 2.22
  */
@@ -697,7 +697,7 @@ _g_resolver_address_to_sockaddr (GInetAddress            *address,
   GSocketAddress *sockaddr;
 
   sockaddr = g_inet_socket_address_new (address, 0);
-  g_socket_address_to_native (sockaddr, (struct sockaddr *)sa, sizeof (*sa));
+  g_socket_address_to_native (sockaddr, (struct sockaddr *)sa, sizeof (*sa), NULL);
   *sa_len = g_socket_address_get_native_size (sockaddr);
   g_object_unref (sockaddr);
 }
